@@ -5,8 +5,8 @@ from albow.core.ResourceUtility import ResourceUtility
 
 from albow.themes.Theme import Theme
 
-from albow.core.Screen import Screen
-from albow.core.Shell import Shell
+from albow.core.ui.Screen import Screen
+from albow.core.ui.Shell import Shell
 
 from albow.widgets.Button import Button
 
@@ -21,15 +21,9 @@ class BaseDemoScreen(Screen):
 
         self.logger = logging.getLogger(__name__)
 
-        screenAttrs = {'bg_color': Theme.WHITE}
-
-        super().__init__(shell=shell, **screenAttrs)
+        super().__init__(shell=shell)
 
         self.smallButtonFont = ResourceUtility.get_font(BaseDemoScreen.SMALL_BUTTON_TEXT_SIZE, Theme.BUILT_IN_FONT)
-        self.backButton      = Button("Back", action=shell.show_menu)
         self.labelFont       = ResourceUtility.get_font(BaseDemoScreen.SMALL_LABEL_TEXT_SIZE, Theme.BUILT_IN_FONT)
 
-        self.labelAttrs = {
-            "bg_color": Theme.WHITE,
-            "fg_color": Theme.BLACK
-        }
+        self.backButton      = Button("Back", action=shell.show_menu, font=self.smallButtonFont)
